@@ -10,7 +10,7 @@ import sys
 import argparse
 from pathlib import Path
 # from flatland.xUML.XumlClassDiagram import XumlClassDiagram
-from xUML.XumlClassDiagram import XumlClassDiagram
+from .xUML.XumlClassDiagram import XumlClassDiagram
 
 # When launched outside of the PyCharm development environment, we need to include all source folders
 # in the sys.path or the flatland imports will fail
